# musicfp
**A terminal based media player for programmers**

------------

## Install

> #### Windows

> ![installing in windows](https://github.com/SatvikVirmani/musicfp/blob/main/assets/install_windows.png?raw=true)

> #### macOS / Linux

> ![installing in linux / macos](https://github.com/SatvikVirmani/musicfp/blob/main/assets/install_linux.png?raw=true) <br />
> `sudo` is neccessary for Linux / macOS users
------------

## Examples

### Playing all songs in a direstory

> #### Windows

> ![playing all songs in windows](https://github.com/SatvikVirmani/musicfp/blob/main/assets/windows.png?raw=true)

> #### macOS / Linux

> ![playing all songs in macOS / linux](https://github.com/SatvikVirmani/musicfp/blob/main/assets/linux.png?raw=true)

### Playing a single song in a directory

> #### Windows

> ![playing single song in windows](https://github.com/SatvikVirmani/musicfp/blob/main/assets/single_windows.png?raw=true)

> #### macOS / Linux

> ![playing single song in macOS / linux](https://github.com/SatvikVirmani/musicfp/blob/main/assets/single_linux.png?raw=true)

------------

## Usage

> ![usage](https://github.com/SatvikVirmani/musicfp/blob/main/assets/usage.png?raw=true)

### Playback controls

> ![playback usage](https://github.com/SatvikVirmani/musicfp/blob/main/assets/usage_playback.png?raw=true)

------------

## Contributing

Contributions, issues and feature requests are welcome!. Feel free to check [Bug Tracker](https://github.com/SatvikVirmani/musicfp/issues "issues") page. To submit improvements or features check [Pull Requests](https://github.com/SatvikVirmani/musicfp/pulls "Pull Requests")
